Cheshire3 Objects: IndexStore

|  | ## Cheshire3 Objects: Index Store

Description

A persistent storage mechanism for indexed terms.

Implementations

- recordStore.BdbIndexStore
  The recommended implementation, it stores the terms in BerkeleyDB stores.

API

Function | Parameters | Returns | Description
--- | --- | --- | ---
__init__ | config, parent |  |
begin_indexing | session, index |  | Setup an environment to allow for batch mode indexing -- eg don't store anything until commit_indexing is called
commit_indexing | session, index |  | Store the terms given since begin_indexing was called
create_index | session, index |  | Register a new index, including maybe creating files on disk and so forth
delete_index | session, index |  | Delete an existing index
contains_index | session, index | Boolean | Does this store maintain the given index
store_terms | session, index, hash, record, ?original |  | Store the given terms and related information, as extracted from the record. If present, store the given original term, as it existed in the record before processing
delete_term | session, index |  | Delete a term from the index
fetch_termList | session, index, term, numberOfTerms, relation, end | list of terms | Return a list of terms and their data according to the parameters. The relation determines which way to scan through the index, and end gives a position to stop at such that 'within' queries can be processed
fetch_term | session, index, term |  | Return the data for a given term
fetch_sortValue | session, index |  | Given a record, return a value appropriate for sorting according to an index. (May not be available)